@@ -1,40 +1,48 @@
 import asyncio
-import datetime
 import gc
 import re
 import sys
-from collections import defaultdict
+import time
+from collections import OrderedDict, defaultdict
 from typing import Any, Optional, Tuple, Union
 
 from ..key import get_template_and_func_for
 from .interface import Backend
 
-__all__ = ("Memory", "MemoryInterval")
+__all__ = "Memory"
+_missed = object()
 
 
 class Memory(Backend):
-    def __init__(self, size: int = 1000, count_stat=False):
-        self.store = {}
+    """
+    Inmemory backend lru with ttl
+    """
+
+    def __init__(self, size: int = 1000, count_stat=False, check_interval=1):
+        self.store = OrderedDict()
+        self._check_interval = check_interval
         self.size = size
         self._count_stat = count_stat
         self._counters = defaultdict(lambda: {"hit": 0, "miss": 0, "set": 0})
-        self._meta = {}
-        self._lock = asyncio.Lock()
         super().__init__()
 
+    async def init(self):
+        asyncio.create_task(self._remove_expired())
+
+    async def _remove_expired(self):
+        while True:
+            for key in dict(self.store):
+                await self.get(key)
+            await asyncio.sleep(self._check_interval)
+
     async def clear(self):
-        async with self._lock:
-            self.store = {}
-            for handler in self._meta.values():
-                handler.cancel()
-            self._meta = {}
+        self.store = OrderedDict()
 
     async def set(self, key: str, value: Any, expire: Union[None, float, int] = None, exist=None) -> bool:
         if exist is not None:
             if not (key in self.store) is exist:
                 return False
-        async with self._lock:
-            self._set(key, value, expire)
+        self._set(key, value, expire)
         return True
 
     async def set_row(self, key: str, value: Any, **kwargs):
@@ -57,70 +65,76 @@ class Memory(Backend):
                 yield key
 
     async def incr(self, key: str):
-        value = int(self._get(key) or 0) + 1
+        value = int(self._get(key, 0)) + 1
         self._set(key=key, value=value)
         return value
 
     async def delete(self, key: str):
-        if key not in self.store:
-            return False
-        async with self._lock:
-            self._delete(key)
+        return self._delete(key)
 
     def _delete(self, key: str) -> bool:
-        del self.store[key]
-        if key in self._meta:
-            del self._meta[key]
-        return True
+        if key in self.store:
+            del self.store[key]
+            return True
+        return False
 
     async def delete_match(self, pattern: str):
         async for key in self.keys_match(pattern):
-            await self.delete(key)
+            self._delete(key)
 
     async def expire(self, key: str, timeout: float):
-        value = self._get(key)
-        if value is None:
+        if not self._key_exist(key):
             return
-        self._set_expire_at(key, datetime.datetime.utcnow() + datetime.timedelta(seconds=timeout))
-
-    def _set_expire_at(self, key, date: datetime.datetime):
-        loop = asyncio.get_event_loop()
-        handler = self._meta.get(key)
-        if handler:
-            handler.cancel()
-        self._meta[key] = loop.call_later((date - datetime.datetime.utcnow()).total_seconds(), self._delete, key)
+        value = self._get(key, default=_missed)
+        if value is _missed:
+            return
+        self._set(key, value, timeout)
 
     async def get_expire(self, key: str) -> int:
-        return -1
+        if key not in self.store:
+            return -1
+        expire_at, _ = self.store[key]
+        return round(expire_at - time.time()) if expire_at is not None else -1
 
     async def ping(self, message: Optional[bytes] = None):
         return b"PONG" if message is None else message
 
     def _set(self, key: str, value: Any, expire: Optional[float] = None):
-        if len(self.store) > self.size:
-            return
         self._count_set(key)
-        self.store[key] = value
-
-        if expire is not None and expire > 0.0:
-            self._set_expire_at(key, datetime.datetime.utcnow() + datetime.timedelta(seconds=expire))
+        expire = time.time() + expire if expire else None
+        if expire is None and key in self.store:
+            expire, _ = self.store[key]
+        self.store[key] = (expire, value)
+        self.store.move_to_end(key)
+        if len(self.store) > self.size:
+            self.store.popitem(last=False)
 
     def _get(self, key: str, default: Optional[Any] = None) -> Optional[Any]:
         self._count_get(key)
-        return self.store.get(key, default)
+        if key not in self.store:
+            return default
+        self.store.move_to_end(key)
+        expire_at, value = self.store.get(key)
+        if expire_at and expire_at < time.time():
+            self._delete(key)
+            return default
+        return value
+
+    def _key_exist(self, key):
+        return self._get(key, default=_missed) is not _missed
 
     async def set_lock(self, key: str, value, expire):
         return await self.set(key, value, expire=expire, exist=False)
 
     async def is_locked(self, key: str, wait=None, step=0.1) -> bool:
         if wait is None:
-            return key in self.store
+            return self._key_exist(key)
         while wait > 0:
-            if key not in self.store:
+            if not self._key_exist(key):
                 return False
             wait -= step
             await asyncio.sleep(step)
-        return key in self.store
+        return self._key_exist(key)
 
     async def unlock(self, key, value) -> bool:
         return self._delete(key)
@@ -156,49 +170,6 @@ class Memory(Backend):
         self._counters[template]["set"] += 1
 
 
-class MemoryInterval(Memory):
-    def __init__(self, size: int = 1000, check_interval: float = 1.0, count_stat=False):
-        self._check_interval = check_interval
-        super().__init__(size=size, count_stat=count_stat)
-
-    async def init(self):
-        asyncio.create_task(self._remove_expired())
-
-    async def _remove_expired(self):
-        while True:
-            store = dict(self.store)
-            for key in store:
-                await self.get(key)
-            await asyncio.sleep(self._check_interval)
-
-    async def get(self, key: str, default: Optional[Any] = None) -> Optional[Any]:
-        expiration = self._meta.get(key)
-        if expiration and datetime.datetime.utcnow() > expiration:
-            await self.delete(key)
-        self._count_get(key)
-        return self.store.get(key, default)
-
-    def _set_expire_at(self, key, date: datetime.datetime):
-        self._meta[key] = date
-
-    def _set(self, key: str, value: Any, expire: Optional[float] = None) -> None:
-        self._count_set(key)
-        self.store[key] = value
-
-        if expire is not None and expire > 0.0:
-            self._set_expire_at(key, datetime.datetime.utcnow() + datetime.timedelta(seconds=expire))
-
-    async def get_expire(self, key: str) -> int:
-        if key in self._meta:
-            return abs(int((datetime.datetime.utcnow() - self._meta[key]).total_seconds()))
-        return -1
-
-    async def clear(self):
-        async with self._lock:
-            self.store = {}
-            self._meta = {}
-
-
 def _get_obj_size(obj) -> int:
     marked = {id(obj)}
     obj_q = [obj]
